#!/bin/bash

JBOSS_HOME=/opt/jboss/wildfly
JBOSS_CLI=$JBOSS_HOME/bin/jboss-cli.sh

function wait_for_wildfly() {
  until `$JBOSS_CLI -c "ls /deployment" &> /dev/null`; do
    sleep 1
  done
}

echo "==> Starting WildFly..."
$JBOSS_HOME/bin/standalone.sh -c standalone-full-ha.xml &

echo "==> Waiting..."
wait_for_wildfly

echo "==> Setup Datasource..."
$JBOSS_CLI -c << EOF
batch

module add --name=org.postgresql --resources=/tmp/postgresql-42.2.4.jar --dependencies=javax.api,javax.transaction.api

/subsystem=datasources/jdbc-driver=postgresql:add(driver-name=postgresql,driver-module-name=org.postgresql,driver-xa-datasource-class-name=org.postgresql.xa.PGXADataSource)

data-source add --jndi-name=$JNDI_NAME --name=$DS_NAME --connection-url=jdbc:postgresql://\${env.DB_HOST}:\${env.DB_PORT}/\${env.DB_NAME} --driver-name=postgresql --user-name=\${env.DB_USER} --password=\${env.DB_PASS}

/subsystem=mail/mail-session=regapp-mail:add(jndi-name=java:/mail/bwIdmMail)
/socket-binding-group=standard-sockets/remote-destination-outbound-socket-binding=regapp-smtp-binding:add(host=localhost,port=25)
/subsystem=mail/mail-session=regapp-mail/server=smtp:add(outbound-socket-binding-ref=regapp-smtp-binding)

jms-queue add --queue-address=bwIdmMailQueue --entries=["queue/bwIdmMailQueue","java:jboss/exported/jms/queue/bwIdmMailQueue"]
jms-queue add --queue-address=bwIdmAsyncJobQueue --entries=["queue/bwIdmAsyncJobQueue","java:jboss/exported/jms/queue/bwIdmAsyncJobQueue"]

/subsystem=logging/logger=org.hibernate.engine.internal.StatisticalLoggingSessionEventListener:add(level=WARN)

/subsystem=undertow/server=default-server/host=default-host/location=\/:remove()
/subsystem=undertow/configuration=handler/file=welcome-content:remove()

run-batch
EOF

echo "==> Shutting down WildFly..."
$JBOSS_CLI -c ":shutdown"

